Check CF-standard met variable coverage for a model/scenario
Source:R/catalog.R
cae_check_variables.RdReports which of the 8 CF-standard met variables are directly available and which need derivation (e.g. prec from rainc + rainnc).
R/catalog.R
cae_check_variables.RdReports which of the 8 CF-standard met variables are directly available and which need derivation (e.g. prec from rainc + rainnc).